@@ -50,7 +50,7 @@ _DEFAULT_EXTENSIONS = [
 async def analyze_repo(
     ctx: AnyContext,
     path: str,
-    goal: str,
+    query: str,
     extensions: list[str] = _DEFAULT_EXTENSIONS,
     exclude_patterns: list[str] = DEFAULT_EXCLUDED_PATTERNS,
     extraction_token_threshold: int | None = None,
@@ -61,33 +61,35 @@ async def analyze_repo(
 
     This tool recursively reads all relevant files in a directory, extracts
     key information, and then summarizes that information in relation to a specific
-    goal. It uses intelligent sub-agents for extraction and summarization, making it
+    query. It uses intelligent sub-agents for extraction and summarization, making it
     ideal for complex tasks that require a holistic understanding of a codebase.
 
     To ensure a focused and effective analysis, it is crucial to provide a
-    clear and specific goal. Vague goals will result in a vague analysis and
+    clear and specific query. Vague queries will result in a vague analysis and
     may cause low quality result.
 
+    The query should also contain all necessary guidelines to perform the analysis.
+
     Make sure to skim the repository or directory first (e.g., by list the file
     names or read the README/docs file) so that you can put effective parameters.
 
     Use this tool for:
     - Understanding a large or unfamiliar codebase.
     - Generating high-level summaries of a project's architecture.
-    - Performing a preliminary code review.
+    - Performing a high-level code review.
     - Creating documentation or diagrams (e.g., "Generate a Mermaid C4 diagram
       for this service").
 
     Args:
         path (str): The path to the directory or repository to analyze.
-        goal (str): A clear and specific description of what you want to
-            achieve. A good goal is critical for getting a useful result.
-            - Good goal: "Understand the database schema by analyzing all the
+        query (str): A clear and specific description of what you want to
+            achieve. A good query is critical for getting a useful result.
+            - Good query: "Understand the database schema by analyzing all the
               .sql files"
-            - Good goal: "Create a summary of all the API endpoints defined in
+            - Good query: "Create a summary of all the API endpoints defined in
               the 'api' directory"
-            - Bad goal: "Analyze the repo"
-            - Bad goal: "Tell me about the code"
+            - Bad query: "Analyze the repo"
+            - Bad query: "Tell me about the code"
         extensions (list[str], optional): A list of file extensions to include
             in the analysis. Defaults to a comprehensive list of common code
             and configuration files.
@@ -117,7 +119,7 @@ async def analyze_repo(
     extracted_infos = await _extract_info(
         ctx,
         file_metadatas=file_metadatas,
-        goal=goal,
+        query=query,
         token_limit=extraction_token_threshold,
     )
     if len(extracted_infos) == 0:
@@ -132,7 +134,7 @@ async def analyze_repo(
         summarized_infos = await _summarize_info(
             ctx,
             extracted_infos=summarized_infos,
-            goal=goal,
+            query=query,
             token_limit=summarization_token_threshold,
         )
     return summarized_infos[0]
@@ -165,7 +167,7 @@ def _get_file_metadatas(
 async def _extract_info(
     ctx: AnyContext,
     file_metadatas: list[dict[str, str]],
-    goal: str,
+    query: str,
     token_limit: int,
 ) -> list[str]:
     extract = create_sub_agent_tool(
@@ -183,7 +185,7 @@ async def _extract_info(
         file_str = json.dumps(file_obj)
         if current_token_count + llm_rate_limitter.count_token(file_str) > token_limit:
             if content_buffer:
-                prompt = json.dumps(_create_extract_info_prompt(goal, content_buffer))
+                prompt = json.dumps(_create_extract_info_prompt(query, content_buffer))
                 extracted_info = await extract(
                     ctx, llm_rate_limitter.clip_prompt(prompt, token_limit)
                 )
@@ -196,7 +198,7 @@ async def _extract_info(
 
     # Process any remaining content in the buffer
     if content_buffer:
-        prompt = json.dumps(_create_extract_info_prompt(goal, content_buffer))
+        prompt = json.dumps(_create_extract_info_prompt(query, content_buffer))
         extracted_info = await extract(
             ctx, llm_rate_limitter.clip_prompt(prompt, token_limit)
         )
@@ -204,9 +206,9 @@ async def _extract_info(
     return extracted_infos
 
 
-def _create_extract_info_prompt(goal: str, content_buffer: list[dict]) -> dict:
+def _create_extract_info_prompt(query: str, content_buffer: list[dict]) -> dict:
     return {
-        "main_assistant_goal": goal,
+        "main_assistant_query": query,
         "files": content_buffer,
     }
 
@@ -214,7 +216,7 @@ def _create_extract_info_prompt(goal: str, content_buffer: list[dict]) -> dict:
 async def _summarize_info(
     ctx: AnyContext,
     extracted_infos: list[str],
-    goal: str,
+    query: str,
     token_limit: int,
 ) -> list[str]:
     summarize = create_sub_agent_tool(
@@ -228,7 +230,9 @@ async def _summarize_info(
         new_prompt = content_buffer + extracted_info
         if llm_rate_limitter.count_token(new_prompt) > token_limit:
             if content_buffer:
-                prompt = json.dumps(_create_summarize_info_prompt(goal, content_buffer))
+                prompt = json.dumps(
+                    _create_summarize_info_prompt(query, content_buffer)
+                )
                 summarized_info = await summarize(
                     ctx, llm_rate_limitter.clip_prompt(prompt, token_limit)
                 )
@@ -239,7 +243,7 @@ async def _summarize_info(
 
     # Process any remaining content in the buffer
     if content_buffer:
-        prompt = json.dumps(_create_summarize_info_prompt(goal, content_buffer))
+        prompt = json.dumps(_create_summarize_info_prompt(query, content_buffer))
         summarized_info = await summarize(
             ctx, llm_rate_limitter.clip_prompt(prompt, token_limit)
         )
@@ -247,8 +251,8 @@ async def _summarize_info(
     return summarized_infos
 
 
-def _create_summarize_info_prompt(goal: str, content_buffer: str) -> dict:
+def _create_summarize_info_prompt(query: str, content_buffer: str) -> dict:
     return {
-        "main_assistant_goal": goal,
+        "main_assistant_query": query,
         "extracted_info": content_buffer,
     }
