@@ -1,4 +1,3 @@
-import json
 from collections.abc import Callable
 from textwrap import dedent
 from typing import TYPE_CHECKING, Any, Coroutine
@@ -9,7 +8,7 @@ from zrb.task.llm.config import get_model, get_model_settings
 from zrb.task.llm.prompt import get_system_and_user_prompt
 
 if TYPE_CHECKING:
-    from pydantic_ai import Agent, Tool
+    from pydantic_ai import Tool
     from pydantic_ai.models import Model
     from pydantic_ai.settings import ModelSettings
     from pydantic_ai.toolsets import AbstractToolset
@@ -24,10 +23,10 @@ def create_sub_agent_tool(
     model: "str | Model | None" = None,
     model_settings: "ModelSettings | None" = None,
     tools: "list[ToolOrCallable]" = [],
-    toolsets: list["AbstractToolset[Agent]"] = [],
+    toolsets: list["AbstractToolset[None]"] = [],
     yolo_mode: bool | list[str] | None = None,
     log_indent_level: int = 2,
-) -> Callable[[AnyContext, str], Coroutine[Any, Any, str]]:
+) -> Callable[[AnyContext, str], Coroutine[Any, Any, dict[str, Any]]]:
     """
     Creates a "tool that is another AI agent," capable of handling complex,
     multi-step sub-tasks.
@@ -61,7 +60,7 @@ def create_sub_agent_tool(
             its final result.
     """
 
-    async def run_sub_agent(ctx: AnyContext, query: str) -> str:
+    async def run_sub_agent(ctx: AnyContext, query: str) -> dict[str, Any]:
         """
         Runs the sub-agent with the given query.
         """
@@ -116,8 +115,8 @@ def create_sub_agent_tool(
 
         # Return the sub-agent's final message content
         if sub_agent_run and sub_agent_run.result:
-            # Return the final message content as a string
-            return json.dumps({"result": sub_agent_run.result.output})
+            # Return the final message content
+            return {"result": sub_agent_run.result.output}
         ctx.log_warning("Sub-agent run did not produce a result.")
         raise ValueError(f"{tool_name} not returning any result")
 
@@ -131,7 +130,7 @@ def create_sub_agent_tool(
             query (str): The query or task for the sub-agent.
 
         Returns:
-            str: The final response or result from the sub-agent.
+            dict[str, Any]: The final response or result from the sub-agent.
         """
     ).strip()
 
