@@ -5,12 +5,15 @@ from datetime import datetime, timezone
 from typing import TYPE_CHECKING, Any, Callable
 
 from zrb.attr.type import StrAttr, StrListAttr
+from zrb.config.config import CFG
 from zrb.config.llm_config import llm_config
 from zrb.config.llm_context.config import llm_context_config
+from zrb.config.llm_context.workflow import LLMWorkflow
 from zrb.config.llm_rate_limitter import llm_rate_limitter
 from zrb.context.any_context import AnyContext
 from zrb.context.any_shared_context import AnySharedContext
 from zrb.task.llm.conversation_history_model import ConversationHistory
+from zrb.task.llm.workflow import get_available_workflows
 from zrb.util.attr import get_attr, get_str_attr, get_str_list_attr
 from zrb.util.file import read_dir, read_file_with_line_numbers
 from zrb.util.llm.prompt import make_prompt_section
@@ -70,23 +73,34 @@ def get_special_instruction_prompt(
     return llm_config.default_special_instruction_prompt
 
 
-def get_modes(
+def get_workflow_names(
     ctx: AnyContext,
-    modes_attr: StrListAttr | None,
-    render_modes: bool,
+    workflows_attr: StrListAttr | None,
+    render_workflows: bool,
+    user_message: str,
 ) -> list[str]:
-    """Gets the modes, prioritizing task-specific, then default."""
-    raw_modes = get_str_list_attr(
+    """Gets the workflows, prioritizing task-specific, then default."""
+    raw_workflows = get_str_list_attr(
         ctx,
-        [] if modes_attr is None else modes_attr,
-        auto_render=render_modes,
+        [] if workflows_attr is None else workflows_attr,
+        auto_render=render_workflows,
     )
-    if raw_modes is None:
-        raw_modes = []
-    modes = [mode.strip().lower() for mode in raw_modes if mode.strip() != ""]
-    if len(modes) > 0:
-        return modes
-    return llm_config.default_modes or []
+    if raw_workflows is not None and len(raw_workflows) > 0:
+        return [w.strip().lower() for w in raw_workflows if w.strip() != ""]
+
+    # Auto select workflows
+    available_workflows = get_available_workflows()
+    selected_workflows = {}
+    for workflow_name, workflow in available_workflows.items():
+        if workflow.default:
+            selected_workflows[workflow_name] = workflow
+        if workflow.when:
+            if re.search(workflow.when, user_message, re.IGNORECASE):
+                selected_workflows[workflow_name] = workflow
+
+    # Sort by priority
+    sorted_workflows = sorted(selected_workflows.values(), key=lambda w: w.priority)
+    return [w.name for w in sorted_workflows]
 
 
 def get_project_context_prompt() -> str:
@@ -101,62 +115,57 @@ def get_project_context_prompt() -> str:
 
 def get_workflow_prompt(
     ctx: AnyContext,
-    modes_attr: StrListAttr | None,
-    render_modes: bool,
+    workflows_attr: StrListAttr | None,
+    render_workflows: bool,
+    user_message: str,
 ) -> str:
-    builtin_workflow_dir = os.path.join(os.path.dirname(__file__), "default_workflow")
-    modes = set(get_modes(ctx, modes_attr, render_modes))
-
-    # Get user-defined workflows
-    workflows = {
-        workflow_name.strip().lower(): content
-        for workflow_name, content in llm_context_config.get_workflows().items()
-        if workflow_name.strip().lower() in modes
-    }
-
-    # Get available builtin workflow names from the file system
-    available_builtin_workflow_names = set()
-    try:
-        for filename in os.listdir(builtin_workflow_dir):
-            if filename.endswith(".md"):
-                available_builtin_workflow_names.add(filename[:-3].lower())
-    except FileNotFoundError:
-        # Handle case where the directory might not exist
-        ctx.log_error(
-            f"Warning: Default workflow directory not found at {builtin_workflow_dir}"
-        )
-    except Exception as e:
-        # Catch other potential errors during directory listing
-        ctx.log_error(f"Error listing default workflows: {e}")
-
-    # Determine which builtin workflows are requested and not already loaded
-    requested_builtin_workflow_names = [
-        workflow_name
-        for workflow_name in available_builtin_workflow_names
-        if workflow_name in modes and workflow_name not in workflows
-    ]
-
-    # Add builtin-workflows if requested
-    if len(requested_builtin_workflow_names) > 0:
-        for workflow_name in requested_builtin_workflow_names:
-            workflow_file_path = os.path.join(
-                builtin_workflow_dir, f"{workflow_name}.md"
-            )
-            try:
-                with open(workflow_file_path, "r") as f:
-                    workflows[workflow_name] = f.read()
-            except FileNotFoundError:
-                ctx.log_error(
-                    f"Warning: Builtin workflow file not found: {workflow_file_path}"
+    available_workflows = get_available_workflows()
+    active_workflow_names = set(
+        get_workflow_names(ctx, workflows_attr, render_workflows, user_message)
+    )
+    available_workflow_prompts = []
+    active_workflow_prompts = []
+    for workflow_name, workflow in available_workflows.items():
+        if workflow_name in active_workflow_names:
+            available_workflow_prompts.append(
+                make_prompt_section(
+                    workflow.name.capitalize(),
+                    "\n".join(
+                        [
+                            f"> Workflow Name: `{workflow.name}`",
+                            f"> Workflow Location: `{workflow.path}`",
+                            workflow.content,
+                        ]
+                    ),
                 )
-            except Exception as e:
-                ctx.log_error(f"Error reading builtin workflow {workflow_name}: {e}")
-
+            )
+            continue
+        active_workflow_prompts.append(
+            make_prompt_section(
+                workflow.name.capitalize(),
+                "\n".join(
+                    [
+                        f"> Workflow Name: `{workflow.name}`",
+                        f"> Description: {workflow.description}",
+                    ]
+                ),
+            )
+        )
+    if len(active_workflow_prompts) > 0:
+        active_workflow_prompts = [
+            "The following workflows are automatically loaded.",
+        ] + active_workflow_prompts
+    if len(available_workflow_prompts) > 0:
+        available_workflow_prompts = [
+            "The following workflows are not automatically loaded.",
+            "Use `load workflow` tool to load necessary workflows based on your current task requirements.",
+        ] + available_workflow_prompts
     return "\n".join(
         [
-            make_prompt_section(header.capitalize(), content)
-            for header, content in workflows.items()
-            if header.lower() in modes
+            make_prompt_section("Active Workflows", "\n".join(active_workflow_prompts)),
+            make_prompt_section(
+                "Available Workflows", "\n".join(available_workflow_prompts)
+            ),
         ]
     )
 
@@ -170,8 +179,8 @@ def get_system_and_user_prompt(
     render_system_prompt: bool = False,
     special_instruction_prompt_attr: StrAttr | None = None,
     render_special_instruction_prompt: bool = False,
-    modes_attr: StrListAttr | None = None,
-    render_modes: bool = False,
+    workflows_attr: StrListAttr | None = None,
+    render_workflows: bool = False,
     conversation_history: ConversationHistory | None = None,
 ) -> tuple[str, str]:
     if conversation_history is None:
@@ -181,14 +190,15 @@ def get_system_and_user_prompt(
     )
     new_system_prompt = _construct_system_prompt(
         ctx=ctx,
+        user_message=user_message,
         persona_attr=persona_attr,
         render_persona=render_persona,
         system_prompt_attr=system_prompt_attr,
         render_system_prompt=render_system_prompt,
         special_instruction_prompt_attr=special_instruction_prompt_attr,
         render_special_instruction_prompt=render_special_instruction_prompt,
-        modes_attr=modes_attr,
-        render_modes=render_modes,
+        workflows_attr=workflows_attr,
+        render_workflows=render_workflows,
         conversation_history=conversation_history,
     )
     user_message_context["Token Counter"] = _get_token_usage_info(
@@ -201,14 +211,15 @@ def get_system_and_user_prompt(
 
 def _construct_system_prompt(
     ctx: AnyContext,
+    user_message: str,
     persona_attr: StrAttr | None = None,
     render_persona: bool = False,
     system_prompt_attr: StrAttr | None = None,
     render_system_prompt: bool = False,
     special_instruction_prompt_attr: StrAttr | None = None,
     render_special_instruction_prompt: bool = False,
-    modes_attr: StrListAttr | None = None,
-    render_modes: bool = False,
+    workflows_attr: StrListAttr | None = None,
+    render_workflows: bool = False,
     conversation_history: ConversationHistory | None = None,
 ) -> str:
     persona = get_persona(ctx, persona_attr, render_persona)
@@ -218,7 +229,9 @@ def _construct_system_prompt(
     special_instruction_prompt = get_special_instruction_prompt(
         ctx, special_instruction_prompt_attr, render_special_instruction_prompt
     )
-    workflow_prompt = get_workflow_prompt(ctx, modes_attr, render_modes)
+    workflow_prompt = get_workflow_prompt(
+        ctx, workflows_attr, render_workflows, user_message
+    )
     project_context_prompt = get_project_context_prompt()
     if conversation_history is None:
         conversation_history = ConversationHistory()
@@ -229,7 +242,23 @@ def _construct_system_prompt(
             make_prompt_section("Persona", persona),
             make_prompt_section("System Prompt", base_system_prompt),
             make_prompt_section("Special Instruction", special_instruction_prompt),
-            make_prompt_section("Special Workflows", workflow_prompt),
+            make_prompt_section(
+                "Special Workflows",
+                "\n".join(
+                    [
+                        "Workflows are SOP/guidelines for performing actions/tasks effectively.",  # noqa
+                        "Always ensure you have all necessary workflows loaded before executing any action/task.",  # noqa
+                        "",
+                        "**Workflow Loading Strategy:**",
+                        "- **Language-specific workflows:** Always load the appropriate programming language workflow when working on projects in that language",  # noqa
+                        "- **Domain-specific workflows:** Load relevant workflows based on the task type (e.g., version control, scripting, content creation)",  # noqa
+                        "- **General workflows:** Load general-purpose workflows that provide foundational best practices for most development tasks",  # noqa
+                        "",
+                        "**Example:** When working on a programming project, always load both the general coding workflow and the specific language workflow.",  # noqa
+                        workflow_prompt,
+                    ]
+                ),
+            ),
             make_prompt_section(
                 "Past Conversation",
                 "\n".join(
@@ -375,13 +404,13 @@ def _extract_user_prompt_components(user_message: str) -> tuple[str, dict[str, A
             ref_type = "directory"
         if content != "":
             # Replace the @-reference in the user message with the placeholder
-            placeholder = f"[Reference {i+1}: {os.path.basename(ref)}]"
+            placeholder = f"[Reference {i+1}: `{os.path.basename(ref)}`]"
             modified_user_message = modified_user_message.replace(
                 f"@{ref}", placeholder, 1
             )
             apendixes.append(
                 make_prompt_section(
-                    f"{placeholder} ({ref_type} path: `{resource_path}`)",
+                    f"Content of {placeholder} ({ref_type} path: `{resource_path}`)",
                     "\n".join(content) if isinstance(content, list) else content,
                     as_code=True,
                 )
